==> owncloud-8.2.2p3.tgz: owncloud/core/l10n/ur_PK.js <==
OC.L10N.register(
    "core",
    {
    "Turned on maintenance mode" : "بحالی موڈ چالو ہے",
    "Turned off maintenance mode" : "بحالی موڈ بند ہے",
    "Updated database" : "اپ ڈیٹ ہوئ ڈیٹا بیس",
    "No image or file provided" : "کوئی تصویر یا فائل فراہم نہیں",
    "Unknown filetype" : "غیر معرروف قسم کی فائل",
    "Invalid image" : "غلط تصویر",
    "No crop data provided" : "کوئی کروپ ڈیٹا ميسر نہیں ",
    "Sunday" : "اتوار",
    "Monday" : "سوموار",
    "Tuesday" : "منگل",
    "Wednesday" : "بدھ",
    "Thursday" : "جمعرات",
    "Friday" : "جمعہ",
    "Saturday" : "ہفتہ",
    "January" : "جنوری",
    "February" : "فرورئ",
    "March" : "مارچ",
    "April" : "اپریل",
    "May" : "مئی",
    "June" : "جون",
    "July" : "جولائی",
    "August" : "اگست",
    "September" : "ستمبر",
    "October" : "اکتوبر",
    "November" : "نومبر",
    "December" : "دسمبر",
    "Settings" : "ترتیبات",
    "Saving..." : "محفوظ ھو رہا ہے ...",
    "seconds ago" : "سیکنڈز پہلے",
    "No" : "نہیں",
    "Yes" : "ہاں",
    "Choose" : "منتخب کریں",
    "Ok" : "اوکے",
    "_{count} file conflict_::_{count} file conflicts_" : ["{گنتی} فائل متصادم ","{گنتی} فائل متصادم "],
    "One file conflict" : "اایک فائل متصادم ہے",
    "New Files" : "جدید فائلیں",
    "Already existing files" : "پہلے سے موجودجدید فائلیں",
    "Which files do you want to keep?" : "آپ کون سی فائلیں رکھنا چاہتے ہیں  ؟",
    "Cancel" : "منسوخ کریں",
    "Continue" : "جاری",
    "(all selected)" : "(سب منتخب شدہ)",
    "({count} selected)" : "({گنتی} منتخب شدہ)",
    "Very weak password" : "بہت کمزور پاسورڈ",
    "Weak password" : "کمزور پاسورڈ",
    "So-so password" : "نص نص پاسورڈ",
    "Good password" : "اچھا پاسورڈ",
    "Strong password" : "مضبوط پاسورڈ",
    "Shared" : "اشتراک شدہ",
    "Error" : "خرابی",
    "Error while sharing" : "اشتراک کے دوران خرابی ",
    "Error while unsharing" : "اشترک ختم کرنے کے دوران خرابی",
    "Error while changing permissions" : "اختیارات کو تبدیل کرنے کے دوران  خرابی ",
    "Error setting expiration date" : "خرابی  تصحیح تاریخ معیاد",
    "Set expiration date" : "تاریخ معیاد سیٹ کریں",
    "Expiration date" : "تاریخ معیاد",
    "Sending ..." : "ارسال ہو رہا ھے",
    "Email sent" : "ارسال شدہ ای میل ",
    "Resharing is not allowed" : "دوبارہ اشتراک کی اجازت نہیں",
    "Share link" : "اشتراک لنک",
    "Password protect" : "محفوظ پاسورڈ",
    "Password" : "پاسورڈ",
    "Choose a password for the public link" : "عوامی لنک کے لئےپاس ورڈ منتخب کریں",
    "Email link to person" : "شحص کے لیے ای میل لنک",
    "Send" : "بھجیں",
    "Shared with you and the group {group} by {owner}" : "آپ اور گروہ سے مشترق شدہ {گروہ } سے {مالک}",
    "Shared with you by {owner}" : "اشتراک شدہ آپ سے{مالک}",
    "Shared in {item} with {user}" : "شراکت میں {آئٹم}اور {مستخدم}",
    "group" : "مجموعہ",
    "notify by email" : "ای میل کے ذریعے مطلع کریں",
    "Unshare" : "شئیرنگ ختم کریں",
    "can edit" : "تبدیل کر سکے ھیں",
    "create" : "نیا بنائیں",
    "delete" : "ختم کریں",
    "access control" : "اسیس کنٹرول",
    "Share" : "اشتراک",
    "Warning" : "انتباہ",
    "The object type is not specified." : "اس چیز کی قسم کی وضاحت نہیں",
    "Enter new" : "جدید درج کریں",
    "Delete" : "حذف کریں",
    "Add" : "شامل کریں",
    "Edit tags" : "ترمیم ٹیگز",
    "Please reload the page." : "براہ مہربانی صفحہ دوبارہ لوڈ کریں.",
    "The update was successful. Redirecting you to ownCloud now." : "اپ ڈیٹ کامیاب تھی۔ اپ کو اون کلوڈ سے منسلک کیا جا رہا ہے",
    "Use the following link to reset your password: {link}" : "اپنا پاسورڈ ری سیٹ کرنے کے لیے اس لنک پر کلک کریں۔  {link}",
    "New password" : "نیا پاسورڈ",
    "Reset password" : "ری سیٹ پاسورڈ",
    "Personal" : "شخصی",
    "Users" : "صارفین",
    "Apps" : "ایپز",
    "Admin" : "ایڈمن",
    "Help" : "مدد",
    "Access forbidden" : "رسائ منقطع ہے",
    "Cheers!" : "واہ!",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "آپ کی ڈیٹا ڈائریکٹری اور فائلیں امکان ہےانٹرنیٹ سے قابل رسائی ہیں کیونکہ htaccess. فائل کام نہیں کرتا ہے",
    "Create an <strong>admin account</strong>" : "ایک<strong> ایڈمن اکاؤنٹ</strong> بنائیں",
    "Username" : "یوزر نیم",
    "Storage & database" : "ذخیرہ اور ڈیٹا بیس",
    "Data folder" : "ڈیٹا فولڈر",
    "Configure the database" : "ڈیٹا بیس کونفگر کریں",
    "Database user" : "ڈیٹابیس یوزر",
    "Database password" : "ڈیٹابیس پاسورڈ",
    "Database name" : "ڈیٹابیس کا نام",
    "Database tablespace" : "ڈیٹابیس ٹیبل سپیس",
    "Database host" : "ڈیٹابیس ہوسٹ",
    "Finish setup" : "سیٹ اپ ختم کریں",
    "Finishing …" : "تکمیل ...",
    "Log out" : "لاگ آؤٹ",
    "Search" : "تلاش",
    "Log in" : "لاگ ان",
    "remember" : "یاد رکھیں",
    "Alternative Logins" : "متبادل لاگ ان ",
    "Thank you for your patience." : "آپ کے صبر کا شکریہ"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.0.7.tgz: owncloud/core/l10n/ur_PK.js <==
OC.L10N.register(
    "core",
    {
    "No image or file provided" : "کوئی تصویر یا فائل فراہم نہیں",
    "Unknown filetype" : "غیر معرروف قسم کی فائل",
    "Invalid image" : "غلط تصویر",
    "No crop data provided" : "کوئی کروپ ڈیٹا ميسر نہیں ",
    "Turned on maintenance mode" : "بحالی موڈ چالو ہے",
    "Turned off maintenance mode" : "بحالی موڈ بند ہے",
    "Updated database" : "اپ ڈیٹ ہوئ ڈیٹا بیس",
    "Sunday" : "اتوار",
    "Monday" : "سوموار",
    "Tuesday" : "منگل",
    "Wednesday" : "بدھ",
    "Thursday" : "جمعرات",
    "Friday" : "جمعہ",
    "Saturday" : "ہفتہ",
    "January" : "جنوری",
    "February" : "فرورئ",
    "March" : "مارچ",
    "April" : "اپریل",
    "May" : "مئی",
    "June" : "جون",
    "July" : "جولائی",
    "August" : "اگست",
    "September" : "ستمبر",
    "October" : "اکتوبر",
    "November" : "نومبر",
    "December" : "دسمبر",
    "Settings" : "ترتیبات",
    "Saving..." : "محفوظ ھو رہا ہے ...",
    "seconds ago" : "سیکنڈز پہلے",
    "No" : "نہیں",
    "Yes" : "ہاں",
    "Choose" : "منتخب کریں",
    "Ok" : "اوکے",
    "_{count} file conflict_::_{count} file conflicts_" : ["{گنتی} فائل متصادم ","{گنتی} فائل متصادم "],
    "One file conflict" : "اایک فائل متصادم ہے",
    "New Files" : "جدید فائلیں",
    "Already existing files" : "پہلے سے موجودجدید فائلیں",
    "Which files do you want to keep?" : "آپ کون سی فائلیں رکھنا چاہتے ہیں  ؟",
    "Cancel" : "منسوخ کریں",
    "Continue" : "جاری",
    "(all selected)" : "(سب منتخب شدہ)",
    "({count} selected)" : "({گنتی} منتخب شدہ)",
    "Very weak password" : "بہت کمزور پاسورڈ",
    "Weak password" : "کمزور پاسورڈ",
    "So-so password" : "نص نص پاسورڈ",
    "Good password" : "اچھا پاسورڈ",
    "Strong password" : "مضبوط پاسورڈ",
    "Shared" : "اشتراک شدہ",
    "Error" : "خرابی",
    "Error while sharing" : "اشتراک کے دوران خرابی ",
    "Error while unsharing" : "اشترک ختم کرنے کے دوران خرابی",
    "Set expiration date" : "تاریخ معیاد سیٹ کریں",
    "Expiration date" : "تاریخ معیاد",
    "Edit" : "تدوین کریں",
    "Choose a password for the public link" : "عوامی لنک کے لئےپاس ورڈ منتخب کریں",
    "Password" : "پاسورڈ",
    "Name" : "اسم",
    "Save" : "حفظ",
    "Sending ..." : "ارسال ہو رہا ھے",
    "Email sent" : "ارسال شدہ ای میل ",
    "Email link to person" : "شحص کے لیے ای میل لنک",
    "Shared with you and the group {group} by {owner}" : "آپ اور گروہ سے مشترق شدہ {گروہ } سے {مالک}",
    "Shared with you by {owner}" : "اشتراک شدہ آپ سے{مالک}",
    "group" : "مجموعہ",
    "notify by email" : "ای میل کے ذریعے مطلع کریں",
    "Unshare" : "شئیرنگ ختم کریں",
    "can edit" : "تبدیل کر سکے ھیں",
    "create" : "نیا بنائیں",
    "delete" : "ختم کریں",
    "access control" : "اسیس کنٹرول",
    "Share" : "اشتراک",
    "Resharing is not allowed" : "دوبارہ اشتراک کی اجازت نہیں",
    "Warning" : "انتباہ",
    "Delete" : "حذف کریں",
    "Rename" : "نام بدلیں",
    "The object type is not specified." : "اس چیز کی قسم کی وضاحت نہیں",
    "Enter new" : "جدید درج کریں",
    "Add" : "شامل کریں",
    "Edit tags" : "ترمیم ٹیگز",
    "Please reload the page." : "براہ مہربانی صفحہ دوبارہ لوڈ کریں.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "اپ ڈیٹ نا کامیاب تھی۔ براہ مہربانی اس مسلے کو رپورٹ کریں اس پے  <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>. ",
    "The update was successful. Redirecting you to ownCloud now." : "اپ ڈیٹ کامیاب تھی۔ اپ کو اون کلوڈ سے منسلک کیا جا رہا ہے",
    "Personal" : "شخصی",
    "Users" : "صارفین",
    "Apps" : "ایپز",
    "Admin" : "ایڈمن",
    "Help" : "مدد",
    "Access forbidden" : "رسائ منقطع ہے",
    "Cheers!" : "واہ!",
    "Create an <strong>admin account</strong>" : "ایک<strong> ایڈمن اکاؤنٹ</strong> بنائیں",
    "Username" : "یوزر نیم",
    "Storage & database" : "ذخیرہ اور ڈیٹا بیس",
    "Data folder" : "ڈیٹا فولڈر",
    "Configure the database" : "ڈیٹا بیس کونفگر کریں",
    "Database user" : "ڈیٹابیس یوزر",
    "Database password" : "ڈیٹابیس پاسورڈ",
    "Database name" : "ڈیٹابیس کا نام",
    "Database tablespace" : "ڈیٹابیس ٹیبل سپیس",
    "Database host" : "ڈیٹابیس ہوسٹ",
    "Finish setup" : "سیٹ اپ ختم کریں",
    "Finishing …" : "تکمیل ...",
    "Log out" : "لاگ آؤٹ",
    "Search" : "تلاش",
    "Log in" : "لاگ ان",
    "Alternative Logins" : "متبادل لاگ ان ",
    "Use the following link to reset your password: {link}" : "اپنا پاسورڈ ری سیٹ کرنے کے لیے اس لنک پر کلک کریں۔  {link}",
    "New password" : "نیا پاسورڈ",
    "Reset password" : "ری سیٹ پاسورڈ",
    "Thank you for your patience." : "آپ کے صبر کا شکریہ"
},
"nplurals=2; plural=(n != 1);");
